"use strict";
var common = require("./tag.common");
function onValuePropertyChanged(data) {
    var tagGroup = data.object;
    if (!tagGroup.android) {
        return;
    }
    var tagList = java.util.Arrays.asList(data.newValue);
    tagGroup.android.setTags(tagList);
}
common.TagGroup.valueProperty.metadata.onSetNativeValue = onValuePropertyChanged;
require("utils/module-merge").merge(common, module.exports);
var TagGroup = (function (_super) {
    __extends(TagGroup, _super);
    function TagGroup() {
        _super.call(this);
        this._editMode = false;
    }
    Object.defineProperty(TagGroup.prototype, "android", {
        get: function () {
            return this._android;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TagGroup.prototype, "ntag_editMode", {
        get: function () {
            return this._editMode;
        },
        set: function (val) {
            if (this._editMode !== val) {
                this._editMode = val;
                this.notifyPropertyChange('ntag_editMode', val);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TagGroup.prototype, "ntag_tagClick", {
        get: function () {
            return this._tagClick;
        },
        set: function (callback) {
            if (this._tagClick !== callback) {
                this._tagClick = callback;
                this.notifyPropertyChange('ntag_tagClick', callback);
            }
        },
        enumerable: true,
        configurable: true
    });
    TagGroup.prototype._createUI = function () {
        this._android = new me.gujun.android.taggroup.TagGroup(this._context);
        this.styleTags();
        if (this.ntag_editMode) {
            var f = this._android.getClass().getDeclaredField("isAppendMode");
            f.setAccessible(true);
            f.setBoolean(this._android, true);
            var tagGroup = this._android;
            var tagGroupClickListener = new android.view.View.OnClickListener({
                onClick: function (view) {
                    tagGroup.submitTag();
                }
            });
            this._android.appendInputTag();
            this._android.setOnClickListener(tagGroupClickListener);
        }
        var that = new WeakRef(this);
        var tagChangeListener = new me.gujun.android.taggroup.TagGroup.OnTagChangeListener({
            onAppend: function (tagGroup, newTag) {
                var instance = that.get();
                if (instance) {
                    var newTags = new java.util.ArrayList(java.util.Arrays.asList(tagGroup.getTags()));
                    instance._onPropertyChangedFromNative(TagGroup.valueProperty, newTags.toArray());
                }
            },
            onDelete: function (tagGroup, deletedTag) {
                var instance = that.get();
                if (instance) {
                    var newTags = new java.util.ArrayList(java.util.Arrays.asList(tagGroup.getTags()));
                    instance._onPropertyChangedFromNative(TagGroup.valueProperty, newTags.toArray());
                }
            }
        });
        this._android.setOnTagChangeListener(tagChangeListener);
        var tagClickListener = new me.gujun.android.taggroup.TagGroup.OnTagClickListener({
            onTagClick: function (tag) {
                var instance = that.get();
                if (instance) {
                    instance.ntag_tagClick(tag);
                }
            }
        });
        this._android.setOnTagClickListener(tagClickListener);
    };
    TagGroup.prototype.styleTags = function () {
        var AndroidColor = android.graphics.Color;
        if (this.ntag_borderColor) {
            var f = this._android.getClass().getDeclaredField("borderColor");
            f.setAccessible(true);
            f.setInt(this._android, AndroidColor.parseColor(this.ntag_borderColor));
        }
        if (this.ntag_textColor) {
            var f = this._android.getClass().getDeclaredField("textColor");
            f.setAccessible(true);
            f.setInt(this._android, AndroidColor.parseColor(this.ntag_textColor));
        }
        if (this.ntag_backgroundColor) {
            var f = this._android.getClass().getDeclaredField("backgroundColor");
            f.setAccessible(true);
            f.setInt(this._android, AndroidColor.parseColor(this.ntag_backgroundColor));
        }
        if (this.ntag_dashBorderColor) {
            var f = this._android.getClass().getDeclaredField("dashBorderColor");
            f.setAccessible(true);
            f.setInt(this._android, AndroidColor.parseColor(this.ntag_dashBorderColor));
        }
        if (this.ntag_inputHintColor) {
            var f = this._android.getClass().getDeclaredField("inputHintColor");
            f.setAccessible(true);
            f.setInt(this._android, AndroidColor.parseColor(this.ntag_inputHintColor));
        }
        if (this.ntag_inputTextColor) {
            var f = this._android.getClass().getDeclaredField("inputTextColor");
            f.setAccessible(true);
            f.setInt(this._android, AndroidColor.parseColor(this.ntag_inputTextColor));
        }
        if (this.ntag_checkedBorderColor) {
            var f = this._android.getClass().getDeclaredField("checkedBorderColor");
            f.setAccessible(true);
            f.setInt(this._android, AndroidColor.parseColor(this.ntag_checkedBorderColor));
        }
        if (this.ntag_checkedTextColor) {
            var f = this._android.getClass().getDeclaredField("checkedTextColor");
            f.setAccessible(true);
            f.setInt(this._android, AndroidColor.parseColor(this.ntag_checkedTextColor));
        }
        if (this.ntag_checkedMarkerColor) {
            var f = this._android.getClass().getDeclaredField("checkedMarkerColor");
            f.setAccessible(true);
            f.setInt(this._android, AndroidColor.parseColor(this.ntag_checkedMarkerColor));
        }
        if (this.ntag_checkedBackgroundColor) {
            var f = this._android.getClass().getDeclaredField("checkedBackgroundColor");
            f.setAccessible(true);
            f.setInt(this._android, AndroidColor.parseColor(this.ntag_checkedBackgroundColor));
        }
        if (this.ntag_pressedBackgroundColor) {
            var f = this._android.getClass().getDeclaredField("pressedBackgroundColor");
            f.setAccessible(true);
            f.setInt(this._android, AndroidColor.parseColor(this.ntag_pressedBackgroundColor));
        }
        if ((this.ntag_small || this.ntag_large) && !(this.ntag_small && this.ntag_large)) {
            var textSize = void 0;
            var hSpacing = void 0;
            var vSpacing = void 0;
            var hPadding = void 0;
            var vPadding = void 0;
            if (this.ntag_small) {
                textSize = 10;
                hSpacing = 6;
                vSpacing = 3;
                hPadding = 8;
                vPadding = 2;
            }
            else if (this.ntag_large) {
                textSize = 15;
                hSpacing = 9;
                vSpacing = 5;
                hPadding = 14;
                vPadding = 4;
                var f_1 = this._android.getClass().getDeclaredField("borderStrokeWidth");
                f_1.setAccessible(true);
                f_1.setFloat(this._android, this._android.dp2px(0.7));
            }
            var f = this._android.getClass().getDeclaredField("textSize");
            f.setAccessible(true);
            f.setFloat(this._android, this._android.sp2px(textSize));
            f = this._android.getClass().getDeclaredField("horizontalSpacing");
            f.setAccessible(true);
            f.setInt(this._android, this._android.dp2px(hSpacing));
            f = this._android.getClass().getDeclaredField("verticalSpacing");
            f.setAccessible(true);
            f.setInt(this._android, this._android.dp2px(vSpacing));
            f = this._android.getClass().getDeclaredField("horizontalPadding");
            f.setAccessible(true);
            f.setInt(this._android, this._android.dp2px(hPadding));
            f = this._android.getClass().getDeclaredField("verticalPadding");
            f.setAccessible(true);
            f.setInt(this._android, this._android.dp2px(vPadding));
        }
        if (this.ntag_textSize) {
            var f = this._android.getClass().getDeclaredField("textSize");
            f.setAccessible(true);
            f.setFloat(this._android, this._android.sp2px(this.ntag_textSize));
        }
        if (this.ntag_borderStrokeWidth) {
            var f = this._android.getClass().getDeclaredField("borderStrokeWidth");
            f.setAccessible(true);
            f.setFloat(this._android, this._android.dp2px(this.ntag_borderStrokeWidth));
        }
        if (this.ntag_horizontalSpacing) {
            var f = this._android.getClass().getDeclaredField("horizontalSpacing");
            f.setAccessible(true);
            f.setInt(this._android, this._android.dp2px(this.ntag_horizontalSpacing));
        }
        if (this.ntag_verticalSpacing) {
            var f = this._android.getClass().getDeclaredField("verticalSpacing");
            f.setAccessible(true);
            f.setInt(this._android, this._android.dp2px(this.ntag_verticalSpacing));
        }
        if (this.ntag_horizontalPadding) {
            var f = this._android.getClass().getDeclaredField("horizontalPadding");
            f.setAccessible(true);
            f.setInt(this._android, this._android.dp2px(this.ntag_horizontalPadding));
        }
        if (this.ntag_verticalPadding) {
            var f = this._android.getClass().getDeclaredField("verticalPadding");
            f.setAccessible(true);
            f.setInt(this._android, this._android.dp2px(this.ntag_verticalPadding));
        }
        if (this.ntag_inputHint) {
            var f = this._android.getClass().getDeclaredField("inputHint");
            f.setAccessible(true);
            f.set(this._android, this.ntag_inputHint);
        }
    };
    return TagGroup;
}(common.TagGroup));
exports.TagGroup = TagGroup;
